@@ -338,7 +338,7 @@ activate_app_def (GtkWidget  *menuitem,
 
 	item = gnome_desktop_item_new_from_uri (
 			item_loc,
-			GNOME_DESKTOP_ITEM_LOAD_NO_TRANSLATIONS,
+			0,
 			&error);
 
 	if (item) {
@@ -1031,10 +1031,17 @@ static void
 add_new_app_to_menu (GtkWidget    *widget,
 		     ShowItemMenu *sim)
 {
+	GtkWidget *dialog;
+	PanelWidget *panel;
+
 	g_return_if_fail (sim->mf != NULL);
 
-	panel_new_launcher (sim->mf->menudir,
-			    menuitem_to_screen (sim->menuitem));
+	panel = menu_get_panel (sim->menuitem);
+
+	dialog = panel_new_launcher (sim->mf->menudir,
+			    	     menuitem_to_screen (sim->menuitem));
+
+	panel_widget_register_open_dialog (panel, dialog);
 }
 
 static void
@@ -1276,8 +1283,22 @@ add_drawers_from_dir (const char  *dirname,
 
 			else if ((g_str_has_suffix (mfile->name, ".desktop") ||
 				  g_str_has_suffix (mfile->name, ".kdelnk")) &&
-				 vfs_text_uri_exists (uri))
-				panel_launcher_create_with_id (attached_toplevel_id, G_MAXINT/2, uri);
+				 vfs_text_uri_exists (uri)) {
+					
+					QuickDesktopItem *qitem;
+
+					qitem = quick_desktop_item_load_uri (uri,
+									     NULL,
+									     TRUE);
+
+					/* Don't add the desktop entry if TryExec fails */
+					if (qitem != NULL) {
+						panel_launcher_create_with_id (
+									   attached_toplevel_id, 
+									   G_MAXINT/2, uri);
+						quick_desktop_item_destroy (qitem);
+					}
+			}
 		}
 
 		g_free (uri);
@@ -1383,6 +1404,8 @@ static void
 edit_dentry (GtkWidget    *widget,
 	     ShowItemMenu *sim)
 {
+	GtkWidget *dialog;
+	PanelWidget *panel;
 	char *dir = NULL;
 
 	g_return_if_fail (sim != NULL);
@@ -1391,20 +1414,32 @@ edit_dentry (GtkWidget    *widget,
 	if (sim->mf)
 		dir = sim->mf->menudir;
 
-	panel_edit_dentry (sim->item_loc, dir,
-			   menuitem_to_screen (sim->menuitem));
+	panel = menu_get_panel (sim->menuitem);
+
+	dialog = panel_edit_dentry (sim->item_loc, dir,
+			   	    menuitem_to_screen (sim->menuitem));
+
+	panel_widget_register_open_dialog (panel, dialog);
 }
 
 static void
 edit_direntry (GtkWidget    *widget,
 	       ShowItemMenu *sim)
 {
+	GtkWidget *dialog;
+	PanelWidget *panel;
+
 	g_return_if_fail (sim != NULL);
 	g_return_if_fail (sim->mf != NULL);
 
-	panel_edit_direntry (sim->mf->menudir,
-			     sim->mf->dir_name,
-			     menuitem_to_screen (sim->menuitem));
+	panel = menu_get_panel (sim->menuitem);
+
+	dialog = panel_edit_direntry (sim->mf->menudir,
+			     	      sim->mf->dir_name,
+				      menuitem_to_screen (sim->menuitem));
+
+	panel_widget_register_open_dialog (panel, dialog);
+	
 }
 
 static void
