@@ -122,7 +122,7 @@ panel_background_prepare (PanelBackground *background)
 	}
 
 	gdk_window_get_user_data (GDK_WINDOW (background->window),
-				  (gpointer *) &widget);
+				  (gpointer) &widget);
 
 	if (GTK_IS_WIDGET (widget))
 	  gtk_widget_queue_draw (widget);
