@@ -1642,6 +1642,33 @@ panel_widget_finalize (GObject *obj)
 	G_OBJECT_CLASS (panel_widget_parent_class)->finalize (obj);
 }
 
+static void
+panel_widget_open_dialog_destroyed (PanelWidget *panel_widget,
+				    GtkWidget   *dialog)
+{
+	g_return_if_fail (panel_widget->open_dialogs != NULL);
+
+	panel_widget->open_dialogs = g_slist_remove (panel_widget->open_dialogs, dialog);
+}
+
+static void
+panel_widget_destroy_open_dialogs (PanelWidget *panel_widget)
+{
+	GSList *l, *list;
+
+	list = panel_widget->open_dialogs;
+	panel_widget->open_dialogs = NULL;
+
+	for (l = list; l; l = l->next) {
+		g_signal_handlers_disconnect_by_func (G_OBJECT (l->data),
+				G_CALLBACK (panel_widget_open_dialog_destroyed),
+				panel_widget);
+		gtk_widget_destroy (l->data);
+	}
+	g_slist_free (list);
+
+}
+
 static void
 panel_widget_destroy (GtkObject *obj)
 {
@@ -1653,6 +1680,8 @@ panel_widget_destroy (GtkObject *obj)
 
 	panels = g_slist_remove (panels, panel);
 
+	panel_widget_destroy_open_dialogs (panel);
+
 	if (panel->master_widget != NULL)
 		g_object_set_data (G_OBJECT (panel->master_widget),
 				   PANEL_APPLET_ASSOC_PANEL_KEY,
@@ -2713,7 +2742,7 @@ static gboolean
 panel_widget_real_focus (GtkWidget        *widget,
                          GtkDirectionType  direction)
 {
-	if (GTK_WIDGET_HAS_FOCUS (widget) && GTK_FIXED (widget)->children) {
+	if (GTK_WIDGET_CAN_FOCUS (widget) && GTK_FIXED (widget)->children) {
 		GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
 	}
 	return GTK_WIDGET_CLASS (panel_widget_parent_class)->focus (widget, direction);
@@ -2856,3 +2885,15 @@ panel_applet_is_in_drag ()
 {
 	return panel_applet_in_drag;
 }
+
+void 
+panel_widget_register_open_dialog (PanelWidget *panel,
+				   GtkWidget   *dialog)
+{
+	panel->open_dialogs = g_slist_append (panel->open_dialogs,
+					      dialog);
+	
+	panel_signal_connect_object_while_alive (dialog, "destroy",
+	 		 G_CALLBACK (panel_widget_open_dialog_destroyed),
+			 panel);
+}
